pub(crate) trait DomGlobal {
// Required method
fn global(&self) -> DomRoot<GlobalScope>;
}Required Methods
Sourcefn global(&self) -> DomRoot<GlobalScope>
fn global(&self) -> DomRoot<GlobalScope>
Returns the relevant global in the same realm as the callee object. Will enter the realm of the global to ensure the global is only accessed from the correct realm.